@@ -31,6 +31,11 @@ class DescribeRecordingRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_NeedVoiceSliceRecording(self): # Boolean
+		return self.get_query_params().get('NeedVoiceSliceRecording')
+
+	def set_NeedVoiceSliceRecording(self, NeedVoiceSliceRecording):  # Boolean
+		self.add_query_param('NeedVoiceSliceRecording', NeedVoiceSliceRecording)
 	def get_ConversationId(self): # String
 		return self.get_query_params().get('ConversationId')
 
