@@ -25,50 +25,44 @@ class DialogueRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'VoiceNavigator', '2018-06-12', 'Dialogue','voicebot')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ConversationId(self):
+	def get_ConversationId(self): # String
 		return self.get_query_params().get('ConversationId')
 
-	def set_ConversationId(self,ConversationId):
-		self.add_query_param('ConversationId',ConversationId)
-
-	def get_CallingNumber(self):
+	def set_ConversationId(self, ConversationId):  # String
+		self.add_query_param('ConversationId', ConversationId)
+	def get_CallingNumber(self): # String
 		return self.get_query_params().get('CallingNumber')
 
-	def set_CallingNumber(self,CallingNumber):
-		self.add_query_param('CallingNumber',CallingNumber)
-
-	def get_InstanceId(self):
+	def set_CallingNumber(self, CallingNumber):  # String
+		self.add_query_param('CallingNumber', CallingNumber)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_CalledNumber(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_CalledNumber(self): # String
 		return self.get_query_params().get('CalledNumber')
 
-	def set_CalledNumber(self,CalledNumber):
-		self.add_query_param('CalledNumber',CalledNumber)
-
-	def get_AdditionalContext(self):
+	def set_CalledNumber(self, CalledNumber):  # String
+		self.add_query_param('CalledNumber', CalledNumber)
+	def get_AdditionalContext(self): # String
 		return self.get_query_params().get('AdditionalContext')
 
-	def set_AdditionalContext(self,AdditionalContext):
-		self.add_query_param('AdditionalContext',AdditionalContext)
-
-	def get_InstanceOwnerId(self):
+	def set_AdditionalContext(self, AdditionalContext):  # String
+		self.add_query_param('AdditionalContext', AdditionalContext)
+	def get_InstanceOwnerId(self): # Long
 		return self.get_query_params().get('InstanceOwnerId')
 
-	def set_InstanceOwnerId(self,InstanceOwnerId):
-		self.add_query_param('InstanceOwnerId',InstanceOwnerId)
-
-	def get_Utterance(self):
+	def set_InstanceOwnerId(self, InstanceOwnerId):  # Long
+		self.add_query_param('InstanceOwnerId', InstanceOwnerId)
+	def get_Utterance(self): # String
 		return self.get_query_params().get('Utterance')
 
-	def set_Utterance(self,Utterance):
-		self.add_query_param('Utterance',Utterance)
\ No newline at end of file
+	def set_Utterance(self, Utterance):  # String
+		self.add_query_param('Utterance', Utterance)
